torchelie.callbacks
===================

Loggers
-------

.. autoclass:: torchelie.callbacks.StdoutLogger
   :members:

.. autoclass:: torchelie.callbacks.VisdomLogger
   :members:

Logging
-------

.. autoclass:: torchelie.callbacks.EpochMetricAvg
   :members:

.. autoclass:: torchelie.callbacks.WindowedMetricAvg
   :members:

.. autoclass:: torchelie.callbacks.Log
   :members:

.. autoclass:: torchelie.callbacks.Counter
   :members:

.. autoclass:: torchelie.callbacks.Throughput
   :members:

Visualization
-------------

.. autoclass:: torchelie.callbacks.ConfusionMatrix
   :members:

.. autoclass:: torchelie.callbacks.MetricsTable
   :members:

.. autoclass:: torchelie.callbacks.ClassificationInspector
   :members:

.. autoclass:: torchelie.callbacks.ImageGradientVis
   :members:

.. autoclass:: torchelie.callbacks.SegmentationInspector
   :members:

Training
--------

.. autoclass:: torchelie.callbacks.Optimizer
   :members:

.. autoclass:: torchelie.callbacks.LRSched
   :members:

Model
-----

.. autoclass:: torchelie.callbacks.Polyak
   :members:

.. autoclass:: torchelie.callbacks.Checkpoint
   :members:

Misc
----

.. autoclass:: torchelie.callbacks.CallRecipe
   :members:

